==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/outputs/ProviderRegistrationPropertiesResponseProviderHubMetadata.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property providerAuthentication
 * @property providerAuthorizations
 * @property thirdPartyProviderAuthorization
 */
public data class ProviderRegistrationPropertiesResponseProviderHubMetadata(
    public val providerAuthentication: ProviderHubMetadataResponseProviderAuthentication? = null,
    public val providerAuthorizations: List<ResourceProviderAuthorizationResponse>? = null,
    public val thirdPartyProviderAuthorization:
    ProviderHubMetadataResponseThirdPartyProviderAuthorization? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.providerhub.outputs.ProviderRegistrationPropertiesResponseProviderHubMetadata):
            ProviderRegistrationPropertiesResponseProviderHubMetadata =
            ProviderRegistrationPropertiesResponseProviderHubMetadata(
                providerAuthentication = javaType.providerAuthentication().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.providerhub.kotlin.outputs.ProviderHubMetadataResponseProviderAuthentication.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                providerAuthorizations = javaType.providerAuthorizations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.providerhub.kotlin.outputs.ResourceProviderAuthorizationResponse.Companion.toKotlin(args0)
                    })
                }),
                thirdPartyProviderAuthorization = javaType.thirdPartyProviderAuthorization().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.providerhub.kotlin.outputs.ProviderHubMetadataResponseThirdPartyProviderAuthorization.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/outputs/ProviderRegistrationPropertiesResponseProviderHubMetadata.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property providerAuthentication
 * @property providerAuthorizations
 * @property thirdPartyProviderAuthorization
 */
public data class ProviderRegistrationPropertiesResponseProviderHubMetadata(
    public val providerAuthentication: ProviderHubMetadataResponseProviderAuthentication? = null,
    public val providerAuthorizations: List<ResourceProviderAuthorizationResponse>? = null,
    public val thirdPartyProviderAuthorization: ProviderHubMetadataResponseThirdPartyProviderAuthorization? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.providerhub.outputs.ProviderRegistrationPropertiesResponseProviderHubMetadata): ProviderRegistrationPropertiesResponseProviderHubMetadata =
            ProviderRegistrationPropertiesResponseProviderHubMetadata(
                providerAuthentication = javaType.providerAuthentication().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.providerhub.kotlin.outputs.ProviderHubMetadataResponseProviderAuthentication.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                providerAuthorizations = javaType.providerAuthorizations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.providerhub.kotlin.outputs.ResourceProviderAuthorizationResponse.Companion.toKotlin(args0)
                    })
                }),
                thirdPartyProviderAuthorization = javaType.thirdPartyProviderAuthorization().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.providerhub.kotlin.outputs.ProviderHubMetadataResponseThirdPartyProviderAuthorization.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
